@@ -4,9 +4,6 @@ set -e
 # pipefail is necessary to propagate exit codes
 set -o pipefail
 
-flake8 --show-source .
-echo -e "No problem detected by flake8\n"
-
 # For docstrings and warnings of deprecated attributes to be rendered
 # properly, the property decorator must come before the deprecated decorator
 # (else they are treated as functions)
@@ -33,11 +30,3 @@ then
     echo "$doctest_directive"
     exit 1
 fi
-
-joblib_import="$(git grep -l -A 10 -E "joblib import.+delayed" -- "*.py" ":!sklearn/utils/_joblib.py" ":!sklearn/utils/fixes.py")"
-
-if [ ! -z "$joblib_import" ]; then
-    echo "Use from sklearn.utils.fixes import delayed instead of joblib delayed. The following files contains imports to joblib.delayed:"
-    echo "$joblib_import"
-    exit 1
-fi
