@@ -8,7 +8,4 @@ elif [[ "$DISTRIB" == "ubuntu" ]]; then
     source $VIRTUALENV/bin/activate
 fi
 
-if [[ "$TEST_DOCSTRINGS" == 'true' ]]; then
-    make test-doc
-    pytest -vsl maint_tools/test_docstring.py
-fi
+make test-doc
