@@ -59,10 +59,9 @@ fig.tight_layout()
 # resampling and the number of samples in the minority class, respectively.
 
 # %%
-import numpy as np
 
 # select only 2 classes since the ratio make sense in this case
-binary_mask = np.bitwise_or(y == 0, y == 2)
+binary_mask = y.isin([0, 1])
 binary_y = y[binary_mask]
 binary_X = X[binary_mask]
 
@@ -91,7 +90,7 @@ ax = y_res.value_counts().plot.pie(autopct=autopct)
 _ = ax.set_title("Over-sampling")
 
 # %% [markdown]
-# `sampling_strategy` has a `str`
+# `sampling_strategy` as a `str`
 # -------------------------------
 #
 # `sampling_strategy` can be given as a string which specify the class
@@ -129,8 +128,8 @@ ax = y_res.value_counts().plot.pie(autopct=autopct)
 _ = ax.set_title("Cleaning")
 
 # %% [markdown]
-# `sampling_strategy as a `dict`
-# ------------------------------
+# `sampling_strategy` as a `dict`
+# -------------------------------
 #
 # When `sampling_strategy` is a `dict`, the keys correspond to the targeted
 # classes. The values correspond to the desired number of samples for each
