@@ -4,18 +4,17 @@
 #          Christos Aridas
 # License: MIT
 
+import numbers
+import warnings
+
 import numpy as np
 from scipy import sparse
+from sklearn.utils import _safe_indexing, check_random_state
 
-from sklearn.utils import check_random_state
-from sklearn.utils import _safe_indexing
-
+from ..utils import Substitution, check_neighbors_object
+from ..utils._docstring import _n_jobs_docstring, _random_state_docstring
+from ..utils._param_validation import HasMethods, Interval
 from .base import BaseOverSampler
-from ..utils import check_neighbors_object
-from ..utils import Substitution
-from ..utils._docstring import _n_jobs_docstring
-from ..utils._docstring import _random_state_docstring
-from ..utils._validation import _deprecate_positional_args
 
 
 @Substitution(
@@ -39,13 +38,26 @@ class ADASYN(BaseOverSampler):
     {random_state}
 
     n_neighbors : int or estimator object, default=5
-        If ``int``, number of nearest neighbours to used to construct synthetic
-        samples.  If object, an estimator that inherits from
-        :class:`~sklearn.neighbors.base.KNeighborsMixin` that will be used to
-        find the k_neighbors.
+        The nearest neighbors used to define the neighborhood of samples to use
+        to generate the synthetic samples. You can pass:
+
+        - an `int` corresponding to the number of neighbors to use. A
+          `~sklearn.neighbors.NearestNeighbors` instance will be fitted in this
+          case.
+        - an instance of a compatible nearest neighbors algorithm that should
+          implement both methods `kneighbors` and `kneighbors_graph`. For
+          instance, it could correspond to a
+          :class:`~sklearn.neighbors.NearestNeighbors` but could be extended to
+          any compatible class.
 
     {n_jobs}
 
+        .. deprecated:: 0.10
+           `n_jobs` has been deprecated in 0.10 and will be removed in 0.12.
+           It was previously used to set `n_jobs` of nearest neighbors
+           algorithm. From now on, you can pass an estimator where `n_jobs` is
+           already set instead.
+
     Attributes
     ----------
     sampling_strategy_ : dict
@@ -61,6 +73,12 @@ class ADASYN(BaseOverSampler):
 
         .. versionadded:: 0.9
 
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during `fit`. Defined only when `X` has feature
+        names that are all strings.
+
+        .. versionadded:: 0.10
+
     See Also
     --------
     SMOTE : Over-sample using SMOTE.
@@ -91,8 +109,7 @@ class ADASYN(BaseOverSampler):
     --------
     >>> from collections import Counter
     >>> from sklearn.datasets import make_classification
-    >>> from imblearn.over_sampling import \
-ADASYN # doctest: +NORMALIZE_WHITESPACE
+    >>> from imblearn.over_sampling import ADASYN
     >>> X, y = make_classification(n_classes=2, class_sep=2,
     ... weights=[0.1, 0.9], n_informative=3, n_redundant=1, flip_y=0,
     ... n_features=20, n_clusters_per_class=1, n_samples=1000,
@@ -105,7 +122,15 @@ ADASYN # doctest: +NORMALIZE_WHITESPACE
     Resampled dataset shape Counter({{0: 904, 1: 900}})
     """
 
-    @_deprecate_positional_args
+    _parameter_constraints: dict = {
+        **BaseOverSampler._parameter_constraints,
+        "n_neighbors": [
+            Interval(numbers.Integral, 1, None, closed="left"),
+            HasMethods(["kneighbors", "kneighbors_graph"]),
+        ],
+        "n_jobs": [numbers.Integral, None],
+    }
+
     def __init__(
         self,
         *,
@@ -124,9 +149,17 @@ ADASYN # doctest: +NORMALIZE_WHITESPACE
         self.nn_ = check_neighbors_object(
             "n_neighbors", self.n_neighbors, additional_neighbor=1
         )
-        self.nn_.set_params(**{"n_jobs": self.n_jobs})
 
     def _fit_resample(self, X, y):
+        # FIXME: to be removed in 0.12
+        if self.n_jobs is not None:
+            warnings.warn(
+                "The parameter `n_jobs` has been deprecated in 0.10 and will be "
+                "removed in 0.12. You can pass an nearest neighbors estimator where "
+                "`n_jobs` is already set instead.",
+                FutureWarning,
+            )
+
         self._validate_estimator()
         random_state = check_random_state(self.random_state)
 
