@@ -12,9 +12,11 @@ composite estimator, as a chain of transforms, samples and estimators.
 #         Christos Aridas
 #         Guillaume Lemaitre <g.lemaitre58@gmail.com>
 # License: BSD
+import sklearn
 from sklearn import pipeline
 from sklearn.base import clone
-from sklearn.utils import Bunch, _print_elapsed_time
+from sklearn.utils import Bunch
+from sklearn.utils.fixes import parse_version
 from sklearn.utils.metaestimators import available_if
 from sklearn.utils.validation import check_memory
 
@@ -34,6 +36,12 @@ METHODS.append("fit_resample")
 
 __all__ = ["Pipeline", "make_pipeline"]
 
+sklearn_version = parse_version(sklearn.__version__).base_version
+if parse_version(sklearn_version) < parse_version("1.5"):
+    from sklearn.utils import _print_elapsed_time
+else:
+    from sklearn.utils._user_interface import _print_elapsed_time
+
 
 class Pipeline(_ParamsValidationMixin, pipeline.Pipeline):
     """Pipeline of transforms and resamples with a final estimator.
@@ -163,11 +171,12 @@ class Pipeline(_ParamsValidationMixin, pipeline.Pipeline):
         for t in transformers:
             if t is None or t == "passthrough":
                 continue
-            if not (
-                hasattr(t, "fit")
-                or hasattr(t, "fit_transform")
-                or hasattr(t, "fit_resample")
-            ) or not (hasattr(t, "transform") or hasattr(t, "fit_resample")):
+
+            is_transfomer = hasattr(t, "fit") and hasattr(t, "transform")
+            is_sampler = hasattr(t, "fit_resample")
+            is_not_transfomer_or_sampler = not (is_transfomer or is_sampler)
+
+            if is_not_transfomer_or_sampler:
                 raise TypeError(
                     "All intermediate steps of the chain should "
                     "be estimators that implement fit and transform or "
@@ -175,9 +184,7 @@ class Pipeline(_ParamsValidationMixin, pipeline.Pipeline):
                     "'%s' (type %s) doesn't)" % (t, type(t))
                 )
 
-            if hasattr(t, "fit_resample") and (
-                hasattr(t, "fit_transform") or hasattr(t, "transform")
-            ):
+            if is_transfomer and is_sampler:
                 raise TypeError(
                     "All intermediate steps of the chain should "
                     "be estimators that implement fit and transform or "
