@@ -272,7 +272,7 @@ def test_pipeline_methods_anova():
     X = iris.data
     y = iris.target
     # Test with Anova + LogisticRegression
-    clf = LogisticRegression(solver="lbfgs", multi_class="auto")
+    clf = LogisticRegression()
     filter1 = SelectKBest(f_classif, k=2)
     pipe = Pipeline([("anova", filter1), ("logistic", clf)])
     pipe.fit(X, y)
@@ -410,7 +410,7 @@ def test_fit_predict_on_pipeline_without_fit_predict():
     scaler = StandardScaler()
     pca = PCA(svd_solver="full")
     pipe = Pipeline([("scaler", scaler), ("pca", pca)])
-    error_regex = "'PCA' object has no attribute 'fit_predict'"
+    error_regex = "has no attribute 'fit_predict'"
     with raises(AttributeError, match=error_regex):
         getattr(pipe, "fit_predict")
 
@@ -639,7 +639,7 @@ def test_classes_property():
 
     clf = make_pipeline(
         SelectKBest(k=1),
-        LogisticRegression(solver="lbfgs", multi_class="auto", random_state=0),
+        LogisticRegression(),
     )
     with raises(AttributeError):
         getattr(clf, "classes_")
@@ -1219,7 +1219,7 @@ def test_score_samples_on_pipeline_without_score_samples():
     pipe.fit(X, y)
     with pytest.raises(
         AttributeError,
-        match="'LogisticRegression' object has no attribute 'score_samples'",
+        match="has no attribute 'score_samples'",
     ):
         pipe.score_samples(X)
 
