@@ -6,6 +6,7 @@ method."""
 # License: MIT
 
 import numbers
+import warnings
 from collections import Counter
 
 import numpy as np
@@ -59,6 +60,16 @@ class CondensedNearestNeighbour(BaseCleaningSampler):
     estimator_ : estimator object
         The validated K-nearest neighbor estimator created from `n_neighbors` parameter.
 
+        .. deprecated:: 0.12
+           `estimator_` is deprecated in 0.12 and will be removed in 0.14. Use
+           `estimators_` instead that contains the list of all K-nearest
+           neighbors estimator used for each pair of class.
+
+    estimators_ : list of estimator objects of shape (n_resampled_classes - 1,)
+        Contains the K-nearest neighbor estimator used for per of classes.
+
+        .. versionadded:: 0.12
+
     sample_indices_ : ndarray of shape (n_new_samples,)
         Indices of the samples selected.
 
@@ -87,8 +98,8 @@ class CondensedNearestNeighbour(BaseCleaningSampler):
     -----
     The method is based on [1]_.
 
-    Supports multi-class resampling. A one-vs.-rest scheme is used when
-    sampling a class as proposed in [1]_.
+    Supports multi-class resampling: a strategy one (minority) vs. each other
+    classes is applied.
 
     References
     ----------
@@ -99,17 +110,20 @@ class CondensedNearestNeighbour(BaseCleaningSampler):
     Examples
     --------
     >>> from collections import Counter  # doctest: +SKIP
-    >>> from sklearn.datasets import fetch_mldata  # doctest: +SKIP
+    >>> from sklearn.datasets import fetch_openml  # doctest: +SKIP
+    >>> from sklearn.preprocessing import scale  # doctest: +SKIP
     >>> from imblearn.under_sampling import \
 CondensedNearestNeighbour  # doctest: +SKIP
-    >>> pima = fetch_mldata('diabetes_scale')  # doctest: +SKIP
-    >>> X, y = pima['data'], pima['target']  # doctest: +SKIP
+    >>> X, y = fetch_openml('diabetes', version=1, return_X_y=True)  # doctest: +SKIP
+    >>> X = scale(X)  # doctest: +SKIP
     >>> print('Original dataset shape %s' % Counter(y))  # doctest: +SKIP
-    Original dataset shape Counter({{1: 500, -1: 268}})  # doctest: +SKIP
+    Original dataset shape Counter({{'tested_negative': 500, \
+        'tested_positive': 268}})  # doctest: +SKIP
     >>> cnn = CondensedNearestNeighbour(random_state=42)  # doctest: +SKIP
     >>> X_res, y_res = cnn.fit_resample(X, y)  #doctest: +SKIP
     >>> print('Resampled dataset shape %s' % Counter(y_res))  # doctest: +SKIP
-    Resampled dataset shape Counter({{-1: 268, 1: 227}})  # doctest: +SKIP
+    Resampled dataset shape Counter({{'tested_positive': 268, \
+        'tested_negative': 181}})  # doctest: +SKIP
     """
 
     _parameter_constraints: dict = {
@@ -142,22 +156,25 @@ CondensedNearestNeighbour  # doctest: +SKIP
     def _validate_estimator(self):
         """Private function to create the NN estimator"""
         if self.n_neighbors is None:
-            self.estimator_ = KNeighborsClassifier(n_neighbors=1, n_jobs=self.n_jobs)
+            estimator = KNeighborsClassifier(n_neighbors=1, n_jobs=self.n_jobs)
         elif isinstance(self.n_neighbors, numbers.Integral):
-            self.estimator_ = KNeighborsClassifier(
+            estimator = KNeighborsClassifier(
                 n_neighbors=self.n_neighbors, n_jobs=self.n_jobs
             )
         elif isinstance(self.n_neighbors, KNeighborsClassifier):
-            self.estimator_ = clone(self.n_neighbors)
+            estimator = clone(self.n_neighbors)
+
+        return estimator
 
     def _fit_resample(self, X, y):
-        self._validate_estimator()
+        estimator = self._validate_estimator()
 
         random_state = check_random_state(self.random_state)
         target_stats = Counter(y)
         class_minority = min(target_stats, key=target_stats.get)
         idx_under = np.empty((0,), dtype=int)
 
+        self.estimators_ = []
         for target_class in np.unique(y):
             if target_class in self.sampling_strategy_.keys():
                 # Randomly get one sample from the majority class
@@ -184,12 +201,11 @@ CondensedNearestNeighbour  # doctest: +SKIP
                 S_y = _safe_indexing(y, S_indices)
 
                 # fit knn on C
-                self.estimator_.fit(C_x, C_y)
+                self.estimators_.append(clone(estimator).fit(C_x, C_y))
 
                 good_classif_label = idx_maj_sample.copy()
                 # Check each sample in S if we keep it or drop it
                 for idx_sam, (x_sam, y_sam) in enumerate(zip(S_x, S_y)):
-
                     # Do not select sample which are already well classified
                     if idx_sam in good_classif_label:
                         continue
@@ -197,7 +213,7 @@ CondensedNearestNeighbour  # doctest: +SKIP
                     # Classify on S
                     if not issparse(x_sam):
                         x_sam = x_sam.reshape(1, -1)
-                    pred_y = self.estimator_.predict(x_sam)
+                    pred_y = self.estimators_[-1].predict(x_sam)
 
                     # If the prediction do not agree with the true label
                     # append it in C_x
@@ -211,12 +227,12 @@ CondensedNearestNeighbour  # doctest: +SKIP
                         C_y = _safe_indexing(y, C_indices)
 
                         # fit a knn on C
-                        self.estimator_.fit(C_x, C_y)
+                        self.estimators_[-1].fit(C_x, C_y)
 
                         # This experimental to speed up the search
                         # Classify all the element in S and avoid to test the
                         # well classified elements
-                        pred_S_y = self.estimator_.predict(S_x)
+                        pred_S_y = self.estimators_[-1].predict(S_x)
                         good_classif_label = np.unique(
                             np.append(idx_maj_sample, np.flatnonzero(pred_S_y == S_y))
                         )
@@ -231,5 +247,15 @@ CondensedNearestNeighbour  # doctest: +SKIP
 
         return _safe_indexing(X, idx_under), _safe_indexing(y, idx_under)
 
+    @property
+    def estimator_(self):
+        """Last fitted k-NN estimator."""
+        warnings.warn(
+            "`estimator_` attribute has been deprecated in 0.12 and will be "
+            "removed in 0.14. Use `estimators_` instead.",
+            FutureWarning,
+        )
+        return self.estimators_[-1]
+
     def _more_tags(self):
         return {"sample_indices": True}
