@@ -3,13 +3,10 @@
 #          Christos Aridas
 # License: MIT
 
-import pytest
 import numpy as np
-
-from sklearn.utils._testing import assert_array_equal
-
 from sklearn.datasets import make_classification
 from sklearn.neighbors import NearestNeighbors
+from sklearn.utils._testing import assert_array_equal
 
 from imblearn.under_sampling import EditedNearestNeighbours
 
@@ -123,13 +120,6 @@ def test_enn_fit_resample_with_nn_object():
     assert_array_equal(y_resampled, y_gt)
 
 
-def test_enn_not_good_object():
-    nn = "rnd"
-    enn = EditedNearestNeighbours(n_neighbors=nn, kind_sel="mode")
-    with pytest.raises(ValueError, match="has to be one of"):
-        enn.fit_resample(X, Y)
-
-
 def test_enn_check_kind_selection():
     """Check that `check_sel="all"` is more conservative than
     `check_sel="mode"`."""
